@@ -1,10 +1,10 @@
 ## File Name: btm.R
-## File Version: 1.498
+## File Version: 1.535
 
 
 #--- Bradley-Terry model in sirt
 btm <- function( data, judge=NULL, ignore.ties=FALSE, fix.eta=NULL, fix.delta=NULL,
-            fix.theta=NULL, maxiter=100, conv=.0001, eps=.3)
+            fix.theta=NULL, maxiter=100, conv=.0001, eps=.3, wgt.ties=.5)
 {
     s1 <- Sys.time()
     CALL <- match.call()
@@ -30,8 +30,12 @@ btm <- function( data, judge=NULL, ignore.ties=FALSE, fix.eta=NULL, fix.delta=NU
 
     # teams
     teams <- unique( sort( c( paste(dat[,1] ), paste(dat[,2] ) ) ) )
-    teams1 <- as.numeric(teams)
-    if ( sum( is.na(teams1))==0 ){ teams <- sort(teams1) }
+    teams1 <- as.numeric(paste(teams))
+
+    if ( sum( is.na(teams1))==0 ){
+        teams <- sort(teams1)
+    }
+
     dat0[,1] <- match( paste( dat0[,1] ), teams )
     dat0[,2] <- match( paste( dat0[,2] ), teams )
     dfr <- data.frame( res1=1*( dat0[,3]==1 ), res0=1*( dat0[,3]==0 ),
@@ -49,12 +53,13 @@ btm <- function( data, judge=NULL, ignore.ties=FALSE, fix.eta=NULL, fix.delta=NU
     r0[ ind2, ] <- r0[ ind2,] + r2
     r3 <- r0
     colnames(r3) <- colnames(dfr)
-    score <- r3[,1]*1 + r3[,3]*1/2
+    score <- r3[,1]*1 + r3[,3]*wgt.ties
     maxscore <- rowSums(r3)
     score_delta <- sum(r1[,3])
-    score_eta <- sum(r1[,1]+r1[,3]/2)
+    score_eta <- sum(r1[,1]+r1[,3]*wgt.ties)
 
     # epsilon adjustment
+    raw <- score
     score <- eps + ( maxscore-2*eps)*score / maxscore
     propscore <- score / maxscore
     # initial ability for each team
@@ -95,6 +100,7 @@ btm <- function( data, judge=NULL, ignore.ties=FALSE, fix.eta=NULL, fix.delta=NU
     maxincr <- 1
     se.delta <- NA
     se.eta <- NA
+    c0 <- Sys.time()
 
     while( ( iter < maxiter ) & ( max.change > conv) ) {
 
@@ -105,7 +111,7 @@ btm <- function( data, judge=NULL, ignore.ties=FALSE, fix.eta=NULL, fix.delta=NU
         M1 <- matrix(0, nrow=ND, ncol=3)
         M1[,1] <- theta[ dat0[,1] ] + eta
         M1[,2] <- theta[ dat0[,2] ]
-        M1[,3] <- delta + ( theta[ dat0[,1] ] + theta[ dat0[,2] ] + eta ) / 2
+        M1[,3] <- delta + ( theta[ dat0[,1] ] + theta[ dat0[,2] ] + eta ) * wgt.ties
 
         M1 <- exp(M1)
         M1 <- M1 / rowSums(M1)
@@ -116,6 +122,12 @@ btm <- function( data, judge=NULL, ignore.ties=FALSE, fix.eta=NULL, fix.delta=NU
 
         maxincr <- maxincr * incrfac
 
+        #--- pre-calculations
+        M13w <- M1[,3]*wgt.ties
+        M11_M13_w <- M1[,1] + M13w
+        wm1 <- wgt.ties - M1[,1] - M1[,3]*wgt.ties
+        wm2 <- wgt.ties - M1[,2] - M1[,3]*wgt.ties
+
         #**** derivatives with respect to delta
         if ( est.delta ){
             d1 <- score_delta - sum( M1[,3] )
@@ -128,9 +140,8 @@ btm <- function( data, judge=NULL, ignore.ties=FALSE, fix.eta=NULL, fix.delta=NU
 
         #*** derivatives with respect to eta
         if ( est.eta ){
-            d1 <- score_eta - sum( M1[,1] + M1[,3]/2 )
-            d2 <- sum( M1[,1] * ( 1 - M1[,1] - M1[,3]/2 ) +
-                                M1[,3]/2 * ( 1/2 - M1[,1] - M1[,3]/2 ) )
+            d1 <- score_eta - sum( M11_M13_w)
+            d2 <- sum( M1[,1] * ( 1 - M11_M13_w ) +    M13w*wm1)
             incr <-  d1 / d2
             incr <- btm_trim_increment(incr=incr, maxincr=maxincr )
             eta <- eta + incr
@@ -139,9 +150,9 @@ btm <- function( data, judge=NULL, ignore.ties=FALSE, fix.eta=NULL, fix.delta=NU
 
         #*** derivatives with respect to theta
         # first derivative
-        fac1 <-  M1[,1] + M1[,3]/2
+        fac1 <-  M1[,1] + M13w
         deriv_theta_i1 <- fac1
-        fac2 <-  M1[,2] + M1[,3]/2
+        fac2 <-  M1[,2] + M13w
         deriv_theta_i2 <- fac2
         # d1a <- ( rowsum( deriv_theta_i1, dat0[,1] )[,1] +
         #             rowsum( deriv_theta_i2, dat0[,2] )[,1] )
@@ -152,10 +163,8 @@ btm <- function( data, judge=NULL, ignore.ties=FALSE, fix.eta=NULL, fix.delta=NU
         d1a[ ind2 ] <- d1a[ ind2 ] + h2
         d1 <- score -  d1a
         # second derivative
-        d2a <- M1[,1]*(1 - M1[,1] - M1[,3] / 2 ) +
-                            M1[,3]/2 * (1/2 - M1[,1] - M1[,3] / 2 )
-        d2b <- M1[,2]*(1 - M1[,2] - M1[,3] / 2 ) +
-                            M1[,3]/2 * (1/2 - M1[,2] - M1[,3] / 2 )
+        d2a <- M1[,1]*(1 - fac1) + M13w*wm1
+        d2b <- M1[,2]*(1 - fac2) + M13w*wm2
         h1 <- rowsum( d2a, dat0[,1] )
         h2 <- rowsum( d2b, dat0[,2] )
         d2 <- rep(1E-20,TP)
@@ -200,42 +209,50 @@ btm <- function( data, judge=NULL, ignore.ties=FALSE, fix.eta=NULL, fix.delta=NU
         utils::flush.console()
 
     }  #---- end algorithm
+    time_alg <- Sys.time() - c0
 
     # arrange output
-    pars <- data.frame("parlabel"=c("Ties", "Home"),
-                        "par"=c("delta", "eta") )
+    pars <- data.frame("parlabel"=c("Ties", "Home"), "par"=c("delta", "eta") )
     pars$est <- c( delta, eta )
     pars$se <- c( se.delta, se.eta )
 
     # estimated individual effect
-    effects <- data.frame( "individual"=teams,
-                            "id"=seq( 1, length(teams) ) )
+    effects <- data.frame( individual=teams, id=seq( 1, length(teams) ) )
     effects$Ntot <- rowSums(r3)
     effects$N1 <- r3[,1]
     effects$ND <- r3[,3]
     effects$N0 <- r3[,2]
+    effects$raw <- raw
     effects$score <- score
     effects$propscore <- propscore
     effects$theta <- theta
     effects$se.theta <- se.theta
     # effects <- effects[ order( effects$theta, decreasing=TRUE), ]
     rownames(effects) <- NULL
+
     # summary of effects parameters
     theta2 <- theta
     theta2[ abs(theta) %in% Inf ] <- NA
-    summary.effects <- data.frame(
-                    "M"=mean(theta2,na.rm=TRUE),
-                    "median"=stats::median(theta),
-                    "SD"=stats::sd(theta2,na.rm=TRUE),
-                    "min"=min(theta), "max"=max(theta) )
+    summary.effects <- data.frame( M=mean(theta2,na.rm=TRUE),
+                    median=stats::median(theta), SD=stats::sd(theta2,na.rm=TRUE),
+                    min=min(theta), max=max(theta) )
 
     # probabilities
     probs <- M1
     colnames(probs) <- c("p1", "p0", "pD")
 
+    # log-likelihood
+    NObs <- nrow(dat0)
+    dat0$result <- dat0[,3]
+    ll <- rep(0,NObs)
+    ll <- ll+log(probs[,1])*(dat0$result==1)
+    ll <- ll+log(probs[,2])*(dat0$result==0)
+    ll <- ll+log(probs[,3])*(dat0$result==.5)
+    ll <- sum(ll)
+
     # fit statistics
     res0 <- btm_fit_statistics( probs=probs, dat0=dat0, ind1=ind1, ind2=ind2,
-                TP=TP, judge=judge )
+                TP=TP, judge=judge, wgt.ties=wgt.ties )
     effects$outfit <- res0$outfit
     effects$infit <- res0$infit
     multiple_judges <- res0$multiple_judges
@@ -247,14 +264,16 @@ btm <- function( data, judge=NULL, ignore.ties=FALSE, fix.eta=NULL, fix.delta=NU
     v0 <- stats::var(effects$theta)
     mle.rel <- 1 - v2 / v0
     sep.rel <- sqrt( v0 / v2 )
-    # output list
+    #--- output list
+    effects <- effects[ order(effects$propscore, decreasing=TRUE), ]
     res <- list( effects=effects, pars=pars, summary.effects=summary.effects,
                 mle.rel=mle.rel, sepG=sep.rel, probs=probs, data=dat0,
                 multiple_judges=multiple_judges, fit_judges=fit_judges,
-                residuals=residuals)
+                residuals=residuals, eps=eps, ignore.ties=ignore.ties,
+                wgt.ties=wgt.ties, time_alg=time_alg, ll=ll, dat=dat)
     res$CALL <- CALL
     res$iter <- iter
-    ic <- list( "n"=length(teams), "D"=nrow(dat0) )
+    ic <- list( n=length(teams), D=nrow(dat0) )
     res$ic <- ic
     s2 <- Sys.time()
     res$s1 <- s1
