@@ -1,5 +1,5 @@
 ## File Name: equating.rasch.R
-## File Version: 0.242
+## File Version: 0.244
 
 
 #---- Equating (linking) in the Rasch model
@@ -18,15 +18,19 @@ equating.rasch <- function( x, y, theta=seq( -4, 4, len=100),
     opt_interval <- 10*c(-1,1)
     #-- Haebara function
     ha <- function(B){
-                fct1 <- .prob.raschtype.genlogis( theta=theta, b=b.xy[,2], alpha1=alpha1, alpha2=alpha2 )
-                fct2 <- .prob.raschtype.genlogis( theta=theta, b=b.xy[,3] - B, alpha1=alpha1, alpha2=alpha2 )
+                fct1 <- .prob.raschtype.genlogis( theta=theta, b=b.xy[,2], alpha1=alpha1,
+                                    alpha2=alpha2 )
+                fct2 <- .prob.raschtype.genlogis( theta=theta, b=b.xy[,3] - B,
+                                    alpha1=alpha1, alpha2=alpha2 )
                 sum( (fct1 - fct2)^2 )
             }
     B.ha <- stats::optimize( f=ha, interval=opt_interval )$minimum
     # Stocking and Lord Approach
     sl <- function(B){
-                fct1 <- .prob.raschtype.genlogis( theta=theta, b=b.xy[,2], alpha1=alpha1, alpha2=alpha2 )
-                fct2 <- .prob.raschtype.genlogis( theta=theta, b=b.xy[,3] - B, alpha1=alpha1, alpha2=alpha2 )
+                fct1 <- .prob.raschtype.genlogis( theta=theta, b=b.xy[,2],
+                                alpha1=alpha1, alpha2=alpha2 )
+                fct2 <- .prob.raschtype.genlogis( theta=theta, b=b.xy[,3] - B,
+                                alpha1=alpha1, alpha2=alpha2 )
                 sum( (rowSums( fct1 - fct2 ) )^2 )
             }
     B.sl <- stats::optimize( f=sl, interval=opt_interval )$minimum
@@ -41,7 +45,8 @@ equating.rasch <- function( x, y, theta=seq( -4, 4, len=100),
     colnames(transf.par) <- c("item", "TransfItempar.Gr1", "Itempar.Gr2"  )
     transf.par <- transf.par[ order( paste(transf.par$item ) ), ]
     # calculate variance and linking error
-    des <- data.frame( "N.Items"=nrow(b.xy), "SD"=stats::sd( b.xy$TransfItempar.Gr1 - b.xy$Itempar.Gr2 ) )
+    des <- data.frame( N.Items=nrow(b.xy),
+                            SD=stats::sd( b.xy$TransfItempar.Gr1 - b.xy$Itempar.Gr2 ) )
     des$Var <- des$SD^2
     des$linkerror <- sqrt( des["SD"]^2 / des["N.Items"] )[1,1]
     #--- output
