@@ -1,11 +1,12 @@
 ## File Name: lsem_estimate_proc_args.R
-## File Version: 0.391
+## File Version: 0.399
 
 lsem_estimate_proc_args <- function(lavaan.args, sufficient_statistics,
     pseudo_weights, lavmodel, data, use_lavaan_survey, est_joint=FALSE,
     par_invariant=NULL, par_linear=NULL, par_quadratic=NULL,
     partable_joint=NULL, se=NULL, G=NULL, moderator.grid=NULL, verbose=TRUE)
 {
+
     use_pseudo_weights <- pseudo_weights > 0
     if ( sufficient_statistics | use_pseudo_weights ){
         use_lavaan_survey <- FALSE
@@ -13,12 +14,7 @@ lsem_estimate_proc_args <- function(lavaan.args, sufficient_statistics,
     if (use_pseudo_weights){
         use_lavaan_survey <- FALSE
     }
-    lavaan_args_names <- names(lavaan.args)
-    if ( "missing" %in% lavaan_args_names){
-        if ( lavaan.args[["missing"]]=="fiml" ){
-            sufficient_statistics <- FALSE
-        }
-    }
+
     #- variables in model
     partable <- sirt_import_lavaan_lavaanify(model=lavmodel)
     variables_model <- intersect( union( partable$lhs, partable$rhs ), colnames(data) )
@@ -40,6 +36,13 @@ lsem_estimate_proc_args <- function(lavaan.args, sufficient_statistics,
         sufficient_statistics <- TRUE
     }
 
+    lavaan_args_names <- names(lavaan.args)
+    if ( "missing" %in% lavaan_args_names){
+        if ( lavaan.args[["missing"]]=="fiml" ){
+            sufficient_statistics <- FALSE
+        }
+    }
+
     #- ordered variables
     variables_ordered <- NULL
     if ("ordered" %in% names(lavaan.args)){
@@ -54,9 +57,11 @@ lsem_estimate_proc_args <- function(lavaan.args, sufficient_statistics,
     for (vv in 1:NV){
         data_ordered[vv] <- is.factor(data1[,vv])
     }
+    some_ordinal <- FALSE
     if (any(data_ordered)){
         sufficient_statistics <- FALSE
         variables_ordered <- union(variables_ordered, names(data_ordered)[data_ordered] )
+        some_ordinal <- TRUE
     }
     if (est_joint & ( ! sufficient_statistics)){
         if (pseudo_weights==0){
@@ -64,7 +69,9 @@ lsem_estimate_proc_args <- function(lavaan.args, sufficient_statistics,
             pseudo_weights <- 10*G*nrow(data)
             use_pseudo_weights <- TRUE
         }
-        stop("Cannot perform joint estimation for non-continuous data.")
+        if (some_ordinal){
+            stop("Cannot perform joint estimation for non-continuous data.")
+        }
     }
     if (is.null(se)){
         if (est_joint){
@@ -81,6 +88,7 @@ lsem_estimate_proc_args <- function(lavaan.args, sufficient_statistics,
                 variables_model=variables_model, use_pseudo_weights=use_pseudo_weights,
                 variables_ordered=variables_ordered, est_joint=est_joint,
                 partable=partable, has_meanstructure=has_meanstructure, se=se,
-                compute_se=compute_se, pseudo_weights=pseudo_weights)
+                compute_se=compute_se, pseudo_weights=pseudo_weights,
+                some_ordinal=some_ordinal)
     return(res)
 }
